module camera_config_ctrl (

	clk,
	nreset,
	enable,
	start_img,
	config_done
	
);

input			clk;
input			nreset; 
input			start_img;
input			enable;
output reg 	config_done;

	// Declare the state register to be "safe" to implement
	// a safe state machine that can recover gracefully from
	// an illegal state (by returning to the reset state).
	(* syn_encoding = "safe" *) reg [1:0] state;
	
	// Declare states
	parameter IDLE = 0, CONFIG = 1, START_IMAGING = 2, RESET = 3;
	
	
	
	// Status signals
	always @ (state) begin
		case (state)
			IDLE:
				config_done = 0;
			CONFIG:
				config_done = 1;
			START_IMAGING:
				config_done = 1;
			RESET:
				config_done = 0;
			default:
				config_done = 0;
		endcase
	end	
	
	// Determine the next state
	always @ (posedge clk) begin
		if (!nreset)
			state <= RESET;
		else
			case (state)
				IDLE:		
					state <= CONFIG;
					
				CONFIG:
					if (start_img)
						state <= START_IMAGING;
					
				START_IMAGING:
					state <= RESET;
					
				RESET:
					state <= IDLE;
					
				default:
					state <= RESET;
			endcase
	end

endmodule