module register_loading (

	clk,
	status,	
	nreset,
	data_in,
	shiftS,
	req,
	data_out
	
);

input					clk; 
input[2:0]			status;
input					nreset;
input[15:0]			data_in;
input 				shiftS;
output				req;
output reg[7:0]	data_out;


reg[7:0]	upperbuffer1, upperbuffer2, lowerbuffer1, lowerbuffer2;

parameter UPPER = 1, LOWER = 0, PRELOADING = 2, IDLE = 3;
(* syn_encoding = "safe" *) reg[1:0] state;

assign req = shiftS;

always @ (posedge clk) begin
	if(!nreset) begin
		data_out <= 0;
		state <= IDLE;
		
		upperbuffer1 <= 0;
		upperbuffer2 <= 0;
		lowerbuffer1 <= 0;
		lowerbuffer2 <= 0;
	end
	else begin
		
		upperbuffer1 <= data_in[15:8];
		lowerbuffer1 <= data_in[7:0];
		
		case(state)
			UPPER:
				if(shiftS) begin
					upperbuffer2 <= upperbuffer1;
					data_out <= lowerbuffer2;
					state <= LOWER;
				end	
				else if(status == 0)  // "idle"
					state <= IDLE;
				else begin
//					data_out <= upperbuffer2;
					state <= UPPER;
				end
			LOWER:
				if(shiftS) begin 
					lowerbuffer2 <= lowerbuffer1;
					data_out <= upperbuffer2;
					state <= UPPER;
				end
				else begin
//					data_out <= lowerbuffer2;
					state <= LOWER;
				end
				
			PRELOADING:
			begin
				upperbuffer2 <= upperbuffer1;
				lowerbuffer2 <= lowerbuffer1;
				state <= LOWER;
			end	
				
			IDLE:
			begin
				if(status == 2)	// "READY"
					state <= PRELOADING;
			end
				
			default:
			begin
				data_out <= 0;
				state <= LOWER;
				
				upperbuffer1 <= 0;
				upperbuffer2 <= 0;
				lowerbuffer1 <= 0;
				lowerbuffer2 <= 0;
			end		
		endcase
	end
end

	
	
endmodule