module main_ctrl (

	clk,
	nreset,
	sreset,	
	command,
	config_done,
	mem_status,
	avg_done,
	start_im,
	enable,
	status
	
);

input					clk; 
input					nreset;
input 				avg_done;
input[1:0]			command;
input 				config_done;
input[4:0]			mem_status;
output reg			start_im;
output reg			enable;
output reg			sreset;		// reset for subordinate control modules
output reg[2:0] 	status;

	// Declare the state register to be "safe" to implement
	// a safe state machine that can recover gracefully from
	// an illegal state (by returning to the reset state).
	(* syn_encoding = "safe" *) reg [2:0] state;
	
	// Declare states
	parameter IDLE = 3'b000, AVG = 3'b001, READY = 3'b010, HIB = 3'b011, RESET = 3'b100;
	parameter NOP = 0, BEGIN = 1, HIBERNATE = 2, ABORT = 3;
	
	// IDLE = waiting to begin
	// AVG = image acquisition and averaging in progress
	// READY = ready to transmit image data_in
	// HIB = hibernating
	
	
	// Status signals to I2C
	always @ (state) begin
		case (state)
			IDLE:
				status = IDLE;
			AVG:
				status = AVG;
			READY:
				status = READY;
			HIB:
				status = HIB;
			default:
				status = IDLE;
		endcase
	end
	
	// Control signals to modules
	always @ (state) begin
		case (state)
			RESET:
			begin
				sreset <= 0;
				start_im <= 0;
				enable <= 1;
			end
			
			IDLE:
			begin
				sreset <= 1;
				start_im <= 0;
				enable <= 1;
			end
			
			AVG:
			begin
				sreset <= 1;
				start_im <= 1;
				enable <= 1;
			end
			
			READY:
			begin
				sreset <= 1;
				start_im <= 0;
				enable <= 1;
			end
	
			HIB:
			begin
				sreset <= 1;				
				start_im <= 0;
				enable <= 0;
			end	
				
			default:
			begin
				start_im <= 0;
				enable <= 1;
				sreset <= 1;
			end
	
		endcase
	end
	
	
	// Determine the next state
	always @ (posedge clk) begin
		if (!nreset)
			state <= RESET;
		else
			case (state)
				IDLE:
					if((command == BEGIN) && config_done)					
						state <= AVG;
					else if(command == HIBERNATE)
						state <= HIB;
					else
						state <= IDLE; 
				AVG:
					if (command == ABORT)
						state <= RESET;
					else if (avg_done)
						state <= READY;
					else
						state <= AVG;
				READY:
					if (command == ABORT)
						state <= RESET;
					else if (mem_status == 0)
						state <= IDLE;
					else
						state <= READY;
						
				HIB:
					if (command == HIBERNATE)
						state <= IDLE;
					else
						state <= HIB;
				RESET:
					state <= IDLE;
				
				default:
					state <= RESET;				
			endcase
	end

endmodule